### 目标

- 嗨球目标没有开放平台接口
- 此 package 用于快速调取嗨球的接口，用于测试等

### 模块开发进度

| 状态   | name         | mod_name      |
| ------ | ------------ | ------------- |
| 未完成 | 用户管理     | account       |
| 未完成 | 数据库管理   | data_server   |
| 未完成 | 教委管理     | office        |
| 完成   | 首页         | home          |
| 未完成 | 职务管理     | role          |
| 未完成 | 运动标签管理 | scheme_label  |
| 未完成 | 学校管理     | tenant        |
| 未完成 | 体育考试     | test_exam     |
| 完成   | 健康标准     | test_standard |
